==> change_labels-1.0.0.tar.gz: change_labels/src/AutoEventSubscriber/ChangeSubmitLabelSubscriber.php <==
<?php

namespace Drupal\change_labels\AutoEventSubscriber;

use Drupal\Core\Entity\ContentEntityFormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\core_event_dispatcher\Event\Form\FormAlterEvent;
use Drupal\core_event_dispatcher\Event\Form\FormBaseAlterEvent;
use Drupal\hook_event_dispatcher\HookEventDispatcherInterface;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeSubmitLabelSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      'hook_event_dispatcher.form_base_entity_form_display_form.alter' => ['addSettingsForm'],
      HookEventDispatcherInterface::FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\core_event_dispatcher\Event\Form\FormBaseAlterEvent $event
   *   Triggering event.
   */
  public function addSettingsForm(FormBaseAlterEvent $event) {
    $entityFormDisplay = $event->getFormState()->getFormObject()->getEntity();
    $form = &$event->getForm();
    $form['change_labels'] = [
      '#type' => 'details',
      '#title' => $this->t('Change labels'),
    ];
    $form['change_labels']['submit_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button label for "Submit"'),
      '#default_value' => $entityFormDisplay->getThirdPartySetting('change_labels', 'submit_label'),
    ];
    $form['#entity_builders'][] = [$this, 'saveThirdPartySettings'];
  }

  /**
   * Entity Builder Callback.
   */
  public function saveThirdPartySettings($entityType, $entityFormDisplay, array &$form, FormStateInterface $formState) {
    if ($formState->getValue('submit_label')) {
      $entityFormDisplay->setThirdPartySetting('change_labels', 'submit_label', $formState->getValue('submit_label'));
      return;
    }

    $entityFormDisplay->unsetThirdPartySetting('change_labels', 'submit_label');
  }

  /**
   * Event handler for altering the submit label of a form.
   *
   * @param \Drupal\core_event_dispatcher\Event\Form\FormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(FormAlterEvent $event) {
    $formObject = $event->getFormState()->getFormObject();
    $form = &$event->getForm();
    if ($formObject instanceof ContentEntityFormInterface &&
      ($display = $formObject->getFormDisplay($event->getFormState())) &&
      isset($form['actions']['submit']['#value'])
    ) {
      $submitReplacement = $display->getThirdPartySetting('change_labels', 'submit_label');
      if ($submitReplacement) {
        $form['actions']['submit']['#value'] = $submitReplacement;
      }
    }
  }

}

==> change_labels-1.0.2.tar.gz: change_labels/src/AutoEventSubscriber/ChangeSubmitLabelSubscriber.php <==
<?php

namespace Drupal\change_labels\AutoEventSubscriber;

use Drupal\Core\Entity\ContentEntityFormInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\core_event_dispatcher\Event\Form\FormAlterEvent;
use Drupal\core_event_dispatcher\Event\Form\FormBaseAlterEvent;
use Drupal\core_event_dispatcher\FormHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Change labels event subscriber.
 */
class ChangeSubmitLabelSubscriber implements EventSubscriberInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      'hook_event_dispatcher.form_base_entity_form_display_form.alter' => ['addSettingsForm'],
      FormHookEvents::FORM_ALTER => ['alterForm'],
    ];
  }

  /**
   * Event handler for the third party settings of a widget.
   *
   * @param \Drupal\core_event_dispatcher\Event\Form\FormBaseAlterEvent $event
   *   Triggering event.
   */
  public function addSettingsForm(FormBaseAlterEvent $event) {
    $entityFormDisplay = $event->getFormState()->getFormObject()->getEntity();
    $form = &$event->getForm();
    $form['change_labels'] = [
      '#type' => 'details',
      '#title' => $this->t('Change labels'),
    ];
    $form['change_labels']['submit_label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Button label for "Submit"'),
      '#default_value' => $entityFormDisplay->getThirdPartySetting('change_labels', 'submit_label'),
    ];
    $form['#entity_builders'][] = [$this, 'saveThirdPartySettings'];
  }

  /**
   * Entity Builder Callback.
   */
  public function saveThirdPartySettings($entityType, $entityFormDisplay, array &$form, FormStateInterface $formState) {
    if ($formState->getValue('submit_label')) {
      $entityFormDisplay->setThirdPartySetting('change_labels', 'submit_label', $formState->getValue('submit_label'));
      return;
    }

    $entityFormDisplay->unsetThirdPartySetting('change_labels', 'submit_label');
  }

  /**
   * Event handler for altering the submit label of a form.
   *
   * @param \Drupal\core_event_dispatcher\Event\Form\FormAlterEvent $event
   *   Triggering event.
   */
  public function alterForm(FormAlterEvent $event) {
    $formObject = $event->getFormState()->getFormObject();
    $form = &$event->getForm();
    if ($formObject instanceof ContentEntityFormInterface &&
      ($display = $formObject->getFormDisplay($event->getFormState())) &&
      isset($form['actions']['submit']['#value'])
    ) {
      $submitReplacement = $display->getThirdPartySetting('change_labels', 'submit_label');
      if ($submitReplacement) {
        $form['actions']['submit']['#value'] = $submitReplacement;
      }
    }
  }

}
